#
# spec file for package thunar
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define libname libthunarx-3-0
%bcond_with git
Name:           thunar
Version:        1.8.15
Release:        lp152.1.1
Summary:        File Manager for the Xfce Desktop Environment
License:        GPL-2.0-or-later
Group:          Productivity/File utilities
URL:            https://docs.xfce.org/xfce/thunar/start
Source:         https://archive.xfce.org/src/xfce/thunar/1.8/%{name}-%{version}.tar.bz2
Source100:      %{name}-rpmlintrc
BuildRequires:  appstream-glib
BuildRequires:  fdupes
BuildRequires:  intltool
BuildRequires:  perl-XML-Parser
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  xfconf
BuildRequires:  pkgconfig(exo-2) >= 0.12.0
BuildRequires:  pkgconfig(gdk-pixbuf-2.0)
BuildRequires:  pkgconfig(gio-2.0)
BuildRequires:  pkgconfig(gio-unix-2.0)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gobject-introspection-1.0) >= 1.30.0
BuildRequires:  pkgconfig(gthread-2.0)
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.22.0
BuildRequires:  pkgconfig(gtk-doc)
BuildRequires:  pkgconfig(gudev-1.0)
BuildRequires:  pkgconfig(ice)
BuildRequires:  pkgconfig(libexif)
BuildRequires:  pkgconfig(libnotify)
BuildRequires:  pkgconfig(libpcre)
BuildRequires:  pkgconfig(libstartup-notification-1.0)
BuildRequires:  pkgconfig(libxfce4kbd-private-3) >= 4.12.0
BuildRequires:  pkgconfig(libxfce4panel-2.0) >= 4.12.0
BuildRequires:  pkgconfig(libxfce4ui-2) >= 4.12.0
BuildRequires:  pkgconfig(libxfce4util-1.0) >= 4.12.0
BuildRequires:  pkgconfig(libxfconf-0) >= 4.12.0
BuildRequires:  pkgconfig(sm)
BuildRequires:  pkgconfig(x11)
%if %{with git}
BuildRequires:  xfce4-dev-tools
%endif
# uses exo-desktop-item-edit, exo-open
Requires:       exo-tools
Recommends:     %{name}-lang = %{version}
Recommends:     gvfs
Recommends:     thunar-volman
Recommends:     tumbler
Recommends:     catfish
Provides:       thunar-doc = %{version}
Obsoletes:      thunar-doc <= 1.2.3

%description
Thunar is a file manager for the Xfce desktop environment. Its
functionality can be extended through plugins. Thunar can also be
extended by writing scripts to be placed in the context menu for
various file types.

%package -n %{libname}
Summary:        Thunar Extension Library
Group:          System/Libraries

%description  -n %{libname}
This package contains the Thunar extension library.

%package devel
Summary:        Development Files for Thunar
Group:          Development/Libraries/C and C++
Requires:       %{libname} = %{version}
Requires:       %{name} = %{version}
Provides:       thunar-devel-doc = %{version}
Obsoletes:      thunar-devel-doc < %{version}

%description devel
This package provides the development files needed for developing extensions for
Thunar.

%package -n typelib-1_0-Thunarx-3_0
Summary:        Thunar Extension Library -- Introspection bindings
Group:          System/Libraries

%description -n typelib-1_0-Thunarx-3_0
This package provides the GObject Introspection bindings for the Thunar extension library %{libname}.

%lang_package

%prep
%autosetup

%build
%if %{with git}
NOCONFIGURE=1 ./autogen.sh
%configure \
    --enable-maintainer-mode \
    --with-helper-path-prefix=%{_libexecdir} \
    --docdir=%{_datadir}/xfce4/thunar \
    --enable-dbus \
    --enable-exif \
    --enable-startup-notification \
    --enable-pcre \
    --enable-gtk-doc \
    --disable-static
%else
%configure \
    --with-helper-path-prefix=%{_libexecdir} \
    --docdir=%{_datadir}/xfce4/thunar \
    --enable-dbus \
    --enable-exif \
    --enable-startup-notification \
    --enable-pcre \
    --enable-gtk-doc \
    --disable-static
%endif
%make_build

%install
%make_install

rm -f %{buildroot}%{_libdir}/*.la \
    %{buildroot}%{_libdir}/thunarx-3/*.la \
    %{buildroot}%{_libdir}/xfce4/panel/plugins/*.la

# add a lowercase manpage symlink
( cd %{buildroot}%{_mandir}/man1/ && ln -sf Thunar.1* \
    $(printf "%%s\n" Thunar.1* | tr [:upper:] [:lower:]) )

# these files are placed under %%{_defaultdocdir}/%%{name} instead
rm -f %{buildroot}%{_datadir}/xfce4/thunar/README.*

# do not allow to Thunar to run as root via pkexec
rm -f %{buildroot}%{_datadir}/polkit-1/actions/org.xfce.thunar.policy

%suse_update_desktop_file -i thunar System Utility Core GTK FileManager
%suse_update_desktop_file -i thunar-bulk-rename System Utility Core GTK Filesystem
%suse_update_desktop_file thunar-settings

%find_lang thunar %{?no_lang_C}

%fdupes %{buildroot}%{_datadir}

appstream-util validate-relax --nonet %{buildroot}%{_datadir}/metainfo/*.appdata.xml

%post -n %{libname} -p /sbin/ldconfig
%postun -n %{libname} -p /sbin/ldconfig

%files
%doc README NEWS AUTHORS FAQ HACKING THANKS TODO docs/README.*
%license COPYING
%dir %{_sysconfdir}/xdg/Thunar
%config %{_sysconfdir}/xdg/Thunar/uca.xml
%{_bindir}/thunar
%{_bindir}/Thunar
%{_bindir}/thunar-settings
%dir %{_libexecdir}/Thunar
%{_libexecdir}/Thunar/ThunarBulkRename
%{_libexecdir}/Thunar/thunar-sendto-email
%{_libexecdir}/systemd/user/thunar.service
%{_libdir}/thunarx-3
%{_libdir}/xfce4/panel/plugins/libthunar-tpa.so
%{_datadir}/Thunar
%{_datadir}/metainfo/org.xfce.thunar.appdata.xml
%{_datadir}/applications/*.desktop
%{_datadir}/dbus-1/services/org.xfce.FileManager.service
%{_datadir}/dbus-1/services/org.xfce.Thunar.service
%{_datadir}/dbus-1/services/org.xfce.Thunar.FileManager1.service
%{_datadir}/icons/hicolor/*/*/*.png
%{_datadir}/icons/hicolor/*/*/*.svg
%{_datadir}/icons/hicolor/*/*/*/*.png
%{_datadir}/pixmaps/Thunar
%{_datadir}/xfce4/panel/plugins/thunar-tpa.desktop
%{_mandir}/man1/thunar.1*
%{_mandir}/man1/Thunar.1*

%files -n %{libname}
%{_libdir}/libthunarx-3.so.*

%files -n typelib-1_0-Thunarx-3_0
%{_libdir}/girepository-1.0/Thunarx-3.0.typelib

%files devel
%doc %{_datadir}/gtk-doc/html/thunarx
%dir %{_includedir}/thunarx-3
%dir %{_includedir}/thunarx-3/thunarx
%{_includedir}/thunarx-3/thunarx/*.h
%{_libdir}/libthunarx-3.so
%{_libdir}/pkgconfig/thunarx-3.pc
%{_datadir}/gir-1.0/Thunarx-3.0.gir

%files lang -f thunar.lang

%changelog
* Sun May 24 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 1.8.15
  * Only open devices after successful mount attempt (bxo#16831)
  * Fix shortcut support for addressbar (bxo#4537 and bxo#13680)
  * Fix crash in bulk renamer on repeated rename (bxo#16824)
  * Add checks for thumbnailer 0 handles (bxo#14122)
  * Replace 'thunar_return_if_fail (THUNAR_IS_DEVICE (device))'
    with standard 'if (..)' to prevent possible crashes. (bxo#13404)
  * Fix check if folder is fully loaded when expanding path
    in tree view.
  * Prevents 100%% CPU load and loosing sync with main view
    in some cases. (bxo#15762)
  * Fixes 100%%CPU on tree-view in some rare cases (bxo#16024)
  * Delete native files faster (bxo#16641)
  * Support libxfce4ui XfceTitledDialog new API (bxo#16616)
  * Translation Updates
* Wed Mar 25 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 1.8.14
  * Revert "Allow opening of multiple file selections (bxo#2487)",
    because it introduced a regression (Not possible any more to DnD
    multiple files in icon/compact view) (bxo#16598)
  * Translation Updates
* Mon Mar 23 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 1.8.13
  * Use tre-view toplevel path of the cursor, if available, in order to
    prevent jumping (bxo#16024)
  * Increase vertical gap between icon and its label slightly (bxo#16041)
  * Fix crash when inserting USB device in tree-view mode. (bxo#15172)
  * Fix jump to Home when ejecting a currently viewed device (bxo#16504)
  * Allow context menu when editing location in pathbar (bxo#16483)
  * Sort device entries in tree view (bxo#16471)
  * Allow to open multiple files at once (bxo#2487)
  * Fix incorrect pathbar autocomplete (bxo#16267)
  * Avoid unreadable names in detailed view (bxo#16391)
  * Prevent crash when renaming files (bxo#10805)
  * Translation Updates
* Fri Jan 31 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 1.8.12
  * NULL is the proper sentinel for g_object_new() (bxo#16310)
  * Drop timer on finalize (bxo#15305)
  * Store column width setting asynchronously and only once (bxo#15305)
  * When move to trash fails, ask whether to delete files (bxo#15975)
  * Ctrl+Mousewheel does not enlarge/shrink entries
    (for detailed list view) (bxo#15936)
  * Extra padding for Eject button when scrollbar is visible (bxo#15312)
  * Use standard icon instead of custom
  * Translation Updates
* Sat Nov 16 2019 Maurizio Galli <maurizio.galli@gmail.com>
- Update to version 1.8.11
  - Thunar 1.8.10 crashing on startup in FreeBSD and Fedora,
    caused by nonfunctional pango version check (bxo#16136, bxo#16138)
  - Translation Updates
* Sun Nov 10 2019 Maurizio Galli <maurizio.galli@gmail.com>
- Update to version 1.8.10
  - Allow compilation with panel 4.15
  - thunar-job: keep track of number of processed files (bxo#16117)
  - No context menu on right-click when started via trash-panel-plugin
    (bxo#16000)
  - icon text now centered after unchecking "Text besides icons"
  - Remove the vertical gap between icon and label (bxo#16041)
  - Fix icon view alignment (bxo#16107)
  - Not possible to grab scrollbar on the very right pixels when maximized
    (bxo#16050)
  - Wrap text of error dialog
  - Not possible to empty the trash via the pathbar context menu
  - Crash on refresh if remote folder has been removed (bxo#15961)
  - Center action buttons in conflict dialog window (bxo#15973)
  - Ensure UCAs use currently selected file path (bxo#15119)
  - make filename label selectable in conflict dialog window
  - Center action buttons in conflict dialog window (bxo#15973)
  - Clear UCA shortcut when the action is deleted
  - Prevent Gtk-CRITICAL when adding or modifying a UCA
  - Thunar SendTo Email: Add missing archive formats (bxo#15917)
  - sendto plugin: fix content type resolution. (bxo#15916)
  - sendto plugin: extract function tse_file_is_archive (bxo#15916)
  - All glory to lowercase (bxo#15394)
  - mismatched names between thunar.appdata.xml and thunar.desktop
    (bxo#15498)
  - Remove superfluous .desktop file "Thunar-folder-handler.desktop.in"
    (bxo#15467)
  - Prevent unnecessary fallback copy-delete in file move when
    overwriting
  - Fix possible memory leak
  - Fix popup menus size (bxo#15832)
  - Add Alt+D as accelerator for Open Location (bxo#15828)
  - Do not insert hyphens at intra-word line breaks (bxo#15856)
- Dropped obsolete patch thunar-1.8-appdata.patch as fixed upstream
  (bxo#15498)
* Fri Aug 16 2019 Maurizio Galli <maurizio.galli@gmail.com>
- Fixed sources in spec file
* Mon Aug 12 2019 Maurizio Galli <maurizio.galli@gmail.com>
- Update to version 1.8.9
  * Remove 'auto-expand folders' from tree-view since it causes bad
    usability with keyboard (bxo#15743)
  * preferences: Add button icons to Help/Close
  * Use designated initializer to avoid compile warnings (bxo#15734)
  * Prevent premature disposal of clipboard manager (bxo#15635)
  * Keep "Open with" menu items updated (bxo#15530)
  * Translation Updates
* Fri Jul 19 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 1.8.8
  * Do not register "send to" as last used app (bxo#14118)
  * Use https where possible
  * Dont restart the folder monitor on each refresh (bxo#13364)
  * Fix XML declaratation in uca.xml (bxo#13623)
  * Always show the executable checkbox (bxo#15605)
  * Replace Trash action with Delete as needed (bxo#15352)
  * Translation updates
* Sat Jun 29 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 1.8.7
  * Fix crash on unmounted volume in tree pane right click (bxo#15452)
  * Do not check G_FILE_ATTRIBUTE_ACCESS_CAN_WRITE anymore (bxo#15367)
  * Deactivate "Move to Trash" menu entry on volumes without trash
    (bxo#15352)
  * thunar-sendto-email.desktop: use xdg mail-send icon (bxo#15499,
    merged thunar-use-xdg-icon-spec-icons.patch upstream)
  * Restore "Empty File" menu icon (bxo#15540)
  * Rename Camelcase to Title Case (bxo#15579)
  * Update mimeapps.list only when necessary (bxo#15533)
  * Prevent new bookmarks on sidebar when dragging files (bxo#14921)
  * Translation updates
* Mon May 20 2019 Maurizio Galli <maurizio.galli@gmail.com>
- Fixed Xfce bug trackers in previous changelog entry
* Mon May 20 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 1.8.6
  * Job is now optional for thunar_io_scan_directory
  * Expand scroll window of file operation progress dialog (bxo#14946)
  * Fix compiler error -Wcast-function-type (GCC 8)
  * Bump glib minimal required version
  * Fix g_type_class_add_private is deprecated
  * Small code cleanup
  * Fix pathbar to on middle click open folders in new tabs (bxo#15302)
  * Translation updates: Danish
- Dropped thunar-job-optional.patch since it was fixed upstream
* Sat May 18 2019 Maurizio Galli <maurizio.galli@gmail.com>
- Added patch from upstream: thunar-job-optional.patch
  prevent Thunar segfault at startup:
  make Job optional for thunar_io_scan_directory
* Sat May 18 2019 Maurizio Galli <maurizio.galli@gmail.com>
- Update to version 1.8.5
  - Do not exit when dbus name registration fails (bxo#15149)
  - tree view jumps (scrolls) when clicking on a directory (bxo#15174)
  - Correctly check if destination is writable (bxo#14718)
  - Make tree-view 'Move to Trash' icon the same as in main pane
  - Make toggle for the delete entry affect tree-view side pane too
  - Pathbar buttons are now resized on folder rename (bxo#15024)
  - Load templates synchronously (bxo#15200)
  - delete key in tree-view can delete the user home folder (bxo#15095)
  - Hide unneeded context menu entries for folder "Trash" in tree view
  - crash after clicking when XDG_SESSION_TYPE isn't set (bxo#15366)
  - man page incorrectly suggests '-v' instead of '-V'
  - Fix how wallpaper is set on Gnome
  - SEGV (11) on USB-flash connection (bxo#13813)
  - Fix session startup priority
  - Fix queued context menu popup
  - Restore right-click drag and drop functionality (bxo#14583)
  - Translation updates
- Dropped obsolete patch thunar-1.8.4-fix-context-menu.patch
- Added conditional %%bcond_with git for building with git master branch
- Updated URL
- Use /metainfo instead of /appdata and drop obsolete file edits
- Other spec file cleanups
* Mon May 13 2019 Maurizio Galli <maurizio.galli@gmail.com>
- Added thunar-1.8.4-fix-context-menu.patch fixing "create document"
  sub-menu not showing any content (boo#1134899)
* Mon Jan 28 2019 Maurizio Galli <maurizio.galli@gmail.com>
- fixed bug trackers in latest changelog
* Mon Jan 28 2019 Maurizio Galli <maurizio.galli@gmail.com>
- Update to 1.8.4
  * Emergency release, triggerd by some trouble with the added support for
    org.freedesktop.FileManager1.service in thunar 1.8.3
  * Renamed org.freedesktop.FileManager1.service.in to
    org.xfce.Thunar.FileManager1.service.in to avoid name clashes (bxo#12414)
  * Dont exit when name org.freedesktop.filemanager1 lost on message-dbus
    (bxo#15088)
  * Translation updates
* Fri Jan 25 2019 Maurizio Galli <maurizio.galli@gmail.com>
- Update to 1.8.3:
  * Thunar sometimes mounts USB drives with root permission (bxo#14719)
  * FreeBSD -Thunar crash due to passing null to strcmp() (bxo#15059)
  * Add support for org.freedesktop.FileManager1 (bxo#12414)
  * Still 8sec delay on logout when there is an open thunar window (bxo#15008)
  * Thunar does not recover directories opened in a previous session (bxo#14969)
  * Thunar utilizes 100%%CPU when the parent directory is not readable (bxo#14900)
  * Add support for CTRL+Z in rename dialog (bxo#14956)
  * Thunar rarely freezes when switching to tree-view (bxo#14960)
  * Crash in tree-view when multiple windows are open (bxo#14714)
  * Improve description of UCA command parameters (bxo#14720)
  * Fixed some Warnings and GLib-GObject-CRITICAL messages
  * Translation updates
- added %%license macro
- added Recommends: catfish for file search
* Mon Oct 15 2018 Maurizio Galli <maurizio.galli@gmail.com>
- update to 1.8.2:
  * Custom actions without an icon could caused the file manager to crash (bxo#14464)
  * Fixed segfault while clicking or typing when using wayland (bxo#14461)
  * Spinner still active after user cancels to mount volume (bxo#14536)
  * Fix standard view border during drag and drop (bxo#14523)
  * Fix build without HAVE_GIO_UNIX (bxo#12863)
  * Fix messed up row-height with disabled "automatically expand columns as needed" in detailed view. (bxo#14548)
  * Add custom date format (bxo#14527)
  * Avoid segfault on file operations (bxo#14281)
  * Update progress when deleting files (bxo#14102)
  * More options for thumbnail size (bxo#14451)
  * Show numeric(%%) progress in file operation dialog (bxo#14102)
  * Add Ctrl+= as alternative accelerator for Zoom In (bxo#14586)
  * Fix UCA forgets keyboard shortcut (bxo#14617)
  * Add preference to open new thunar instances as tabs (bxo#13314)
  * Add support for folder.jpg (bxo#14576)
  * Show file size in binary units by default (bxo#14653)
  * Removed start limit from Bulk Renamer to rename by number (bxo#14437)
  * Added preferences item to toggle 'delete' in the context menu (bxo#13327)
  * Added infobox to preferences in order to inform about missing gvfs
  * Right mouse click will not display icons for custom actions (bxo#14685)
  * Allow tabs switch with Ctrl + PgUp/PgDown (bxo#9585)
  * Many minor styling fixes
  * Translation updates
* Fri Jun 15 2018 seife+obs@b1-systems.com
- update to 1.8.1:
  - Downgrade libxfce4-ui required version to 4.12.0
  - Bump exo version to 0.12.0
  - Use symbolic icon for edit button in pathbar
  - Add the right-click menu item "Open with" as well for folders
- 1.8.0:
  - GTK3 Port
  - Replace dbus-glib with GDBus
  - Improved Pathbar style for Location Selector
  - Bump thunarx to version 3 and replace GtkAction with
    ThunarxMenu and ThunarxMenuItem
  - GObject-Introspection support for thunarx-3
  - Regression: Context menu misplaced (bxo#14216)
  - Prevent crash after updating thunar if old thunar deamon is
    still running
  - many other bugfixes, see NEWS file
- rebase / rename thunar-appdata.patch to thunar-1.8-appdata.patch
* Thu Apr 26 2018 seife+obs@b1-systems.com
- update to 1.6.15:
  * Thunar User Configurable Actions do not work for remote
    locations (bxo#7652), patch from (bxo#7305)
  * replaced links to "http://thunar.xfce.org/" with
    "https://docs.xfce.org/xfce/thunar/Start/"
  * SIGSEGV when thumbnailer is under heavy load after opening many
    tabs (bxo#13756)
  * Fixed creation of .desktop file when dropping URL into folder
    (bxo#14239)
  * Restoring non-empty folders leaves copy in Trash (bxo#13535)
  * Translation updates
- packaging: do not package huge ChangeLog, NEWS is enough
* Sun Feb 18 2018 jengelh@inai.de
- Ensure neutrality of description.
* Sat Feb 17 2018 seife+obs@b1-systems.com
- update to 1.6.14:
  * Do not translate "Trash" files and folders (bxo#14211)
  * Crash in thunar_file_is_gfile_ancestor (bxo#14202)
  * Fix potential buffer overflow (bxo#12444)
  * Fix crash on unavailable file move copy (bxo#14056)
  * Translation updates
- partly spec-cleaner fixes
* Tue Nov 28 2017 seife+obs@b1-systems.com
- update to 1.6.13:
  * Handle cases when file watch is not supported (bxo#13881)
  * Missing Trash Translation String (bxo#13409)
  * Handle g_mem_is_system_malloc deprecation
  * Prefer local (file://) URIs than native ones (e.g. smb://)
    (bxo#13845), fixes drag-and-drop to third-party apps.
  * Translation updates
* Fri Jul  7 2017 seife+obs@b1-systems.com
- Update to 1.6.12:
  * Fix deadlock in mutex causing Thunar to hang (bxo#13481)
  * Add support for Exif:ImageDescription and Exif:UserComment
  * Do not pass NULL to g_file_test
  * Bump libxfce4panel version for TPA plugin to 4.9.0
  * Switch from XfcePanelImage to GtkImage
  * Fixed a compilation error with the newest dev panel API
  * Translation updates: Catalan, Dutch (Flemish), Galician,
    Korean, Lithuanian, Spanish, Thai
* Mon Apr 17 2017 antoine.belvire@opensuse.org
- Update to 1.6.11:
  * Fix a crash for on cut/pasting of multiple files (bxo#12260)
  * Fix a crash when renaming files (bxo#12264)
  * Fix missing return value for debug in thunar_file_reload
    (bxo#12827)
  * Fix thunar history being deleted after view change (bxo#12708)
  * Expand the name column by default in details view (bxo#11357)
  * Silently ignore G_IO_ERROR_FAILED_HANDLED (bxo#8695)
  * Fixing missing return value in standard view
  * Fix crashes when reloading target file after move (bxo#11983)
  * Translation updates: Arabic, Asturian, Basque, Bulgarian,
    Catalan, Croatian, Danish, Dutch (Flemish), English
    (Australia), English (Great Britain), Finnish, French,
    Galician, German, Greek, Hebrew, Hungarian, Icelandic, Italian,
    Korean, Lithuanian, Norwegian Bokmal, Norwegian Nynorsk,
    Occitan, Portuguese, Portuguese (Brazilian), Slovak, Swedish
- Remove thunar-bugfixes.patch (fixed upstream)
* Wed Feb 22 2017 ronnypeine@gmx.de
- Created patch thunar-bugfixes.patch fixing the following upstream bugs:
  - Fix a crash for on cut/pasting of multiple files (bxo #12260)
  - Fix a crash when renaming files (boo #1011518, bxo #12264)
  - Fix missing return value for debug in thunar_file_reload (bxo #12827)
  - Fix thunar history being deleted after view change (bxo #12708)
  - Fixing missing return value in standard view
  - Fix crashes when reloading target file after move (bxo #11983)
* Tue Jan 26 2016 davejplater@gmail.com
- Created thunar-appdata.patch to correct mismatched names between
  thunar.appdata.xml and thunar.desktop. Renamed Thunar.desktop to
  thunar.desktop to solve installation system problems see:
  boo#952324
* Fri May 22 2015 gber@opensuse.org
- update to version 1.6.10
  - Do not track thunar/thunar-marshal.{c,h}
  - Remove Makefile and Makefile.in files when running distclean
  - Remove subversion $Id$ tags
  - Really fix trash state at startup (bxo#9513, bxo#11913)
  - Use proper return type for thunar_file_reload (bxo#11913)
  - Revert "Fix loading the trash bin status at startup (bxo#9513)"
* Sun May 17 2015 gber@opensuse.org
- update to version 1.6.9
  - fix ThunarBulkRename script not supporting spaces (bxo#9713)
  - use "Name" column for drag & drop instead of first column
    (bxo#11905)
  - update the path entry icon when current file changes
  - revert changes for restoring the trash in the session client
    (bxo#9513)
  - fix loading the trash bin status at startup (bxo#9513)
  - turn off building gtk-docs API reference
  - fix cppcheck warning about uninitialized variable
  - disable "Set as default application" by default in the chooser
    dialog
  - remember chosen application in the chooser dialog as last used
  - remember the last used application when opening files
  - fix reload when file is replaced with directory of the same
    name
  - do listen for G_FILE_MONITOR_EVENT_ATTRIBUTE_CHANGED
    (bxo#11896)
  - fix comments for toggle-menubar
  - allow opening by middle-click in tree view only for mounted
    devices and resources
  - keep selection in original tree view when middle-clicking for
    new tab/window
  - keep path selected after unmounting a device via KEY_Left
  - unmount device if collapsing a collapsed device tree with
    KEY_Left in the tree view
  - fix wrong network icon shown in tree view
  - fix tree view opening mounted devices in new tab
  - use only open selection instead of open action with KEY_Up and
    KEY_Down
  - fix assertion when hitting KEY_Left on a top-level item in the
    tree view
  - revert workaround for desktop toplevel item in the tree view
  - always select the proper toplevel item in the thunar tree view
  - unescape URI in history error message
  - remove unmounted files from history when going back or forward
  - translation updates
* Tue May  5 2015 gber@opensuse.org
- update to version 1.6.8
  - watch for CHANGES_DONE_HINT instead of CHANGED and
    ATTRIBUTE_CHANGED (bxo#8377)
  - shortcut view: Fix "selection in selection" graphical bug when
    renaming shortcut
  - fix broken shortcut renaming (bxo#11885)
  - unescape URIs in the shortcut view (bxo#10831)
  - fix compiler warning because of missing curly braces
  - fix compilation error because of wrong variable name
  - fix unescaping of local paths in path entry (bxo#8190)
  - fix escaping and unescaping URI in path entry (bxo#8910)
  - let the tree view keep the focus when clicking on an item
    (bxo#11863)
  - fix switching to the 10th tab via <alt>-<0> keyboard shortcut
  - fix removal of a directory wrongly affecting the current tab
    (bxo#10981)
  - keep the scroll position when restoring the file selection
  - restore selection only when rows-reordered signal is received
    (bxo#11855)
  - for folders copied always append "copy #" to the end of their
    names (bxo#11862)
  - update F5 binding for new ThunarWindow::reload signal
  - do not perform the complete folder reload in idle (bxo#11849)
  - Coverity CID 60623: Unused value
  - Coverity CID 60621: Missing return statement
  - Coverity CID 60620: Explicit null dereferenced
  - Coverity CID 60619: Explicit null dereferenced
  - Coverity CID 60617: Unchecked return value
  - remove unused variable in thunar_standard_view_set_history
  - remove startup notification dependencies (bxo#11837)
  - translation updates
* Mon Apr 20 2015 gber@opensuse.org
- update to version 1.6.7
  - Improve drag & drop and selecting in the details view
    (bxo#11605)
  - Let row changes accumulate a bit before restoring selection
  - Implement reloading file information on manual reload
  - Extend reload functions to allow a full reload
  - Check in thunar-marshal with new
    _thunar_marshal_BOOLEAN__BOOLEAN
  - Reload files changed by jobs in an idle loop (bxo#11008)
  - Refactor code for moving thumbnail cache file on renames/moves
  - Rework thunar_file_monitor to properly register moved files
  - Add function to reload parent file of a file
  - Fix updating file info for moved files (bxo#11008)
  - Revert "Refresh file info after getting it from cache
    (bxo#11008)"
  - Fix comments
  - Update the location bar after reload (bxo#10518)
  - Fix updating custom actions (bxo#11749)
  - Update rows on changes of case-sensitive and folders-first
    settings
  - Fix typos and grammar mistakes in a few comments
  - Make new windows inherit the history of the origin view
    (bxo#5538)
  - Make new tabs inherit the history of the origin view (bxo#5538)
  - Keep the history across view changes (bxo#10171)
  - Implement functions for copying the history of a view
  - Rename tsv_restore_selection to tsv_select_after_row_deleted
  - Redraw the details view on row changes
  - Restore selection on row changes too (bxo#9886)
  - Improve mouse wheel zoom behaviour
  - Remember and restore file selection on view changes
  - Restore file selection when changing sort order (bxo#9886)
  - Update model with changed binary file size setting immediately
  - Fix typo busy_pulse in thunar-shortcuts-model.c
  - Fix typo in thunar-clipboard-manager
  - Fix Gdk-CRITICAL error
  - Clean up more files with make clean
  - Rework usage of binary file size properties (bxo#11450)
  - Remove duplicate break statement in thunar-standard-view
  - Fix compiler warning about shadowing 'basename' (bxo#11633)
  - thunar/thunar-dbus-service-infos.xml corrections
  - Fix startup id handling for launch requests over D-Bus
    (bxo#9646)
  - Fallback to non-cached version of source file (bxo#9142)
  - Translation updates
* Sat Feb 28 2015 gber@opensuse.org
- update to version 1.6.6
  - Removed GNU extension -i from sed
  - Bump default size of file properties dialog a bit
  - Respect the "View new folders using" preference (bxo#11606)
  - Improve check for shell scripts and add hidden option for
    bxo#7596
  - Fix some GTK_STOCK icon usages resulting in missing icons
    (bxo#11608)
  - plugins/thunar-wallpaper: Fix icon
  - Fix icon name for folders and a memory leak (bxo#11608)
  - Also query for network location icons
  - Don't use deprecated function
  - Secure threading in the idle thumbnail loading
  - Sidepane treeview: Do not switch folder when clicking a row
    expander
  - Fix cppcheck possible errors/warnings
  - Hide template file extensions in context menu (bxo#11571)
  - thunar-wallpaper: Fix translation in applications other than
    thunar
  - thunar-wallpaper: Check if file is really an image (bxo#11565)
  - Update another copyright string
  - Fix endless rename loop in case of error on the properties
    dialog (bxo#11557)
  - Translation updates
* Fri Feb 20 2015 gber@opensuse.org
- update to version 1.6.5
  - bump autotools versions
  - add .gitignore
  - do not execute but only open shell scripts by default
    (bxo#7596) (Harald Judt)
  - fix typo in error message (Nick Schermer)
  - improve keyboard navigation for thunar-tree-view (bxo#4519)
    (Harald Judt)
  - allow ctrl + middle click in shortcut and treeview panes
    (Harald Judt)
  - set correct dialog window hint for progress dialog (bxo#11467)
    (Matt Thirtytwo)
  - refresh file info after getting it from cache (bxo#11008)
    (Peter de Ridder)
  - remove unused enum for signal handlers (bxo#11493) (Matt
    Thirtytwo)
  - simplify Makefile.am, generated files are separated from typed
    source files (Matt Thirtytwo)
  - thunar-tpa: Install desktop file to
    $(datadir)/xfce4/panel/plugins (Robby Workman)
  - fix anchor offset in xfce_dialog_show_help () function
    (Olivier Duchateau)
  - properly handle m4 stuff (Harald Judt)
  - TWP: Single-workspace-mode = TRUE is the default (bxo#11047)
    (Eric Koegel)
  - thunar-wallpaper: Do not use escaped filenames for xfconf
    (Harald Judt)
  - use xfconf and handle xfdesktop's single workspace (bxo#11047)
    (Eric Koegel)
  - revert "Workaround for crashes on RHEL5" (Andrzej)
  - revert "Fallback to image surface, workaround for bug in
    Cairo/RENDER" (Andrzej)
  - renaming a file from another file manager, file disappears in
    Thunar window (bxo#11430) (Andrzej)
  - make usage/free string more clear (bxo#11345) (Harald Judt)
  - make single middle click open files and folders (bxo#10587)
    (Harald Judt)
  - add a progressbar to the freespace indicator in the properties
    dialog (Harald Judt, Simon Steinbeiss)
  - change resize style in thunar-wallpaper plugin (Thaddaeus
    Tintenfisch)
  - add vim modeline, remove obsolete '$Id$' line (Matt Thirtytwo)
  - right click context menu with wrong icon (bxo#10652) (Andrzej)
  - translation updates
* Mon Jan  5 2015 gber@opensuse.org
- update to version 1.6.4
  - make distcheck fix (reference docs linking error) (Andrzej)
  - Add support for binary file size units (bxo#10864)
    (Andre Miranda)
  - Strip trailing spaces/Github test (Nick)
  - Fix case of Xfce in appdata description (Simon)
  - Update intltool (Eric)
  - Add pkexec policy (bxo#11122) (Eric)
  - Remove trailing whitespace from Makefile to prevent warning
    (Simon)
  - Add appdata file for Thunar (Bug 11172) (Eric)
  - Check for thumbnails in the new location (bxo#11263) (Eric)
  - Default application not respected with glib >= 2.41
    (bxo#11212) (Guido)
  - Add support for the GTK 3 bookmarks file (bxo#10627)
    (Alistair)
  - Update xfconf setting for thunar-wallpaper plugin (Eric)
  - Update copyright. (Nick)
  - thunar-tpa: fix libxfce4panel version checking macros
    (Andrzej)
  - Fallback to image surface, workaround for bug in
    Cairo/RENDER (Andrzej)
  - Fixed missing inode-directory/folder icons on old systems.
    (Andrzej)
  - Change name of file copies (and links) (bxo#7518). (Nick)
  - Improve the extension selection to not match hidden names.
    (Nick)
  - Safe accels 10 sec after changes (bxo#10139). (Nick)
  - Force icons on the toolbar (bxo#10179). (Nick)
  - Improve handling of renames (bxo#10242). (Nick)
  - Smarter file extension selecting (bxo#10268). (Jeff Shipley)
  - I18n: Remove broken / unsupported translations. (Nick)
  - Force reference on files from the cache. (Nick)
  - Drop README.thunarrc. (Nick)
  - Translation updates.
- remove obsolete thunar-fix-default-application-lookup.patch.
  thunar-support-gtk3-bookmarks.patch
* Tue Oct 14 2014 gber@opensuse.org
- add thunar-support-gtk3-bookmarks.patch in order to add support
  for the GTK 3 bookmarks file (bxo#10627)
- add thunar-fix-default-application-lookup.patch in order to fix
  the default application lookup with gio >= 2.41 (bxo#11212)
* Thu Oct  2 2014 crrodriguez@opensuse.org
- Do not BuildRequire xorg-x11-devel, just pkgconfig(sm)
  and pkgconfig(x11)
* Sun May  5 2013 gber@opensuse.org
- update to version 1.6.3
  - autotools updates
  - allow keyboard shortcuts for user customizable actions
  - prepend and later reverse for collecting selection
  - some optimizations in renamer loop
  - plug leak in file renamer
  - escape name for sidepane tooltips
  - revert "Remove image resolution from statusbar."
  - fix segfault when going back to removed directory
  - translation updates
* Thu May  2 2013 gber@opensuse.org
- modified thunar-use-xdg-icon-spec-icons.patch in order to fix the
  thuar-sento-email icon
* Fri Dec 28 2012 gber@opensuse.org
- update to version 1.6.2
  - don't abort startup if dbus failed
  - put * around string if * and ? are not used in the pattern
  - revert "Remove right-click drag possibility (bug #3549)."
  - revert "Directly popup menus on selected items (bug #3550)."
  - update shortcuts headers when removing a shortcut
  - implement tab middle click in location buttons
  - add new tab option to right-click menu of location buttons
  - small improvement in thumbnail frame
  - key combos not working with location buttons
  - open tree node if expanded and mounted
  - use some more cairo rendering
  - make Desktop in Go menu translatable
  - send to menu not updated for directories
  - fix freeze on /proc/kmsg
  - show all volumes in the devices list
  - removed translations: Dzongkha, Kazakh, Kurdish, Macedonian
  - translation updates
* Tue Dec 18 2012 gber@opensuse.org
- package NEWS file
* Mon Dec 17 2012 gber@opensuse.org
- update to version 1.6.1
  - tabs support
  - performance improvements
  - numerous bugfixes
  - see the included NEWS file for a detailed list of changes
- rebased thunar-use-xdg-icon-spec-icons.patch
* Wed May  9 2012 gber@opensuse.org
- add versioned dependencies
* Sun Apr 29 2012 gber@opensuse.org
- update to version 1.4.0
  - add a 64x64 and 128x128 icon for Thunar
  - move away from the hard-coded size of window icons
  - link against gmodule
  - don't use deprecated g_format_size_for_display
  - don't use g_atexit anymore
  - use mount operations with eject and unmount
  - unref mount operation from sendto menu
  - translation updates
- depend on exo-tools, thunar uses exo-desktop-item-edit, exo-open
- renamed thunar-fix-terminal-icon-name.patch to
  thunar-use-xdg-icon-spec-icons.patch and replace xfce-filemanager
  which is provided by libxfcegui4 with system-file-manager
* Thu Apr 19 2012 gber@opensuse.org
- obsolete thunar-doc properly
* Sat Apr 14 2012 gber@opensuse.org
- update to version 1.3.2
  - support small property for trash panel applet
  - make uca.xml readable for humans
  - enable startup-notify in the uca example
  - hide thumb queue cleanup debug and plug memleak
  - plug more leaks in thumbnailer
  - reload ThunarView if job finishes
  - use macro to get uri where possible
  - free string in progress view
  - fix file selection problems
  - free module list in provider factory
  - use a normal ExoBinding to avoid mem leak
  - bump 4util and 4ui dependencies
  - translation updates
* Thu Apr 12 2012 gber@opensuse.org
- added thunar-fix-terminal-icon-name.patch in order to use a
  generic icon for "Open in terminal" action that conforms to the
  XDG Icon Naming Spec
* Sun Apr  8 2012 gber@opensuse.org
- update to version 1.3.1
  - fix crash when trying to thumbnail a file with unknown content
    type
  - fix properties dialog crash with files with unknown content
    type
  - fix crash when hovering a CD drive with a special icon
  - use portable abicheck.sh from xfconf
  - avoid segfaults due to interpreting display names as format
    strings
  - improve the UI according to bugs #7496 and #7497
  - treat backup files as hidden as with thunar-vfs
  - fix crash when opening a mountable drive with no media
    in a way that does not break SMB shares
  - fix segfaults in case icons are missing or not found
  - allow exec bit of MS-DOS executables and MSI to be changed
  - prevent falling back to an unexpected locale
  - show translated names of desktop files
  - fix sorting of filenames with large numbers
  - respect ThunarIconFactory::show-thumbnails. Fixes a regression
  - fix crash when removing an ancestor of the current folder
  - fix handling %%U when launching multiple files with an app
  - improve sorting of file names that include numbers
  - add a "Skip All" button to the file overwrite dialog
  - compress icons and images
  - remove the manual
  - use 32 instead of 36 pixels for small icons
  - show Thunar settings in category
  - don't update UI more then fourth per second in deep count job
  - fix sorting of applications in chooser dialog
  - depend on Gtk 2.20 and Glib 2.24 and drop some workarounds
  - fix removing custom application launchers again
  - prevent looping in some renamers
  - fix segfault when plugin returns a NULL suffix
  - remove spec file, rpm build and update libtool
  - lowercase the thunar executable and install a Thunar symlink
  - make the clipboard persistence
  - use glib functions for get/set cwd
  - don't interpret file display names as format strings
  - paste files in correct order
  - fix truncated strings when loading and storing emblems
  - only erase top-level items from trash
  - don't interpret file display names as format strings
  - ship stock_folder-copy.png and stock_folder-move.png icons with
    Thunar itself
  - fix segfault when calling strcasecmp with NULL parameters
  - only change the Name field when renaming desktop files
  - force desktop file reload after changing the Name field
  - fix memory leak caused by not destroying the rename job
  - allow installation of helper scripts in a custom location using
    the --with-helper-path-prefix=PATH configure option
  - improve thumbnailing by avoid sending thumbnail requests while
    the user is scrolling in a directory
  - cancel thumbnail requests when leaving a directory
  - avoid regenerating thumbnails when files are copied, moved,
    linked or trashed
  - update the thumbnail cache when files are deleted permanently
  - translation updates
- drop obsolete thunar-allow-custom-helper-dir.patch
- drop thunar-fix-desktop-files.patch and edit desktop file instead
* Tue Mar 27 2012 gber@opensuse.org
- specfile cleanup
* Tue Mar 20 2012 gber@opensuse.org
- merged -devel-doc into -devel
- specfile cleanup
- corrected dependencies
- rename thunarx-refrence-images.tar.bz2 to
  thunarx-reference-images.tar.bz2
- removed thunar-sendto-bluetooth.desktop, gnome-bluetooth is
  is not in the Xfce pattern any more
* Thu Oct 20 2011 gber@opensuse.org
- install HTML documentation under /usr/share/xfce4/Thunar/html
- package COPYING
* Fri Oct 14 2011 gber@opensuse.org
- recommend gvfs
* Fri Oct 14 2011 gber@opensuse.org
- added thunar-sendto-bluetooth.desktop in order to easily allow
  sending files via bluetooth
- recommend -doc subpackage
* Tue Sep 20 2011 gber@opensuse.org
- update to version 1.2.3
  - use glib functions for get/set cwd
  - revert "Speed up initial start by loading the network item later
  - on installation create relative paths in symlinks to images
  - allow exec bit of MS-DOS executables and MSI to be changed
  - prevent falling back to an unexpected locale
  - show translated names of desktop files
  - bugfixes
  - translation updates
- dropped obsolete
  thunar-1.2.2-fix-crash-opening-drive-with-no-media.patch and
  thunar-1.2.2-fix-crash-with-missing-icons.patch
* Tue Sep 20 2011 gber@opensuse.org
- added thunar-1.2.2-fix-crash-opening-drive-with-no-media.patch
  which fixes a crash when opening a drive with no media
  (backported from upstream git)
- added thunar-1.2.2-fix-crash-with-missing-icons.patch which fixes
  a crash when icons are missing or not found (backported from
  upstream git)
* Sun Jul 24 2011 gber@opensuse.org
- added thunarx-refrence-images.tar.bz2 with the images missing
  from the source tarball (bxo#7838)
* Tue Jul 19 2011 gber@opensuse.org
- added thunar-allow-custom-helper-dir.patch in order to allow the
  installation of helpers under libexecdir
- added patch tags
* Tue Jul 19 2011 gber@opensuse.org
- "update" to version 1.2.2 which is the most recent stable
  release whereas 1.3.x is the current development branch; this
  version has been released after 1.3.0 and contains additional
  bugfixes and translation updates not present in 1.3.0
- removed obsolete thunar-CVE-2011-1588.patch
* Tue May 17 2011 prusnak@opensuse.org
- fixed CVE-2011-1588 [bnc#687874]
* Fri Feb 18 2011 gber@opensuse.org
- update to version 1.3.0
  - only change the Name field when renaming desktop files
  - force desktop file reload after changing the Name field
  - allow installation of helper scripts in a custom location using
    the --with-helper-path-prefix=PATH configure option
  - improve thumbnailing by avoid sending thumbnail requests while
    the user is scrolling in a directory
  - cancel thumbnail requests when leaving a directory
  - avoid regenerating thumbnails when files are copied, moved,
    linked or trashed
  - update the thumbnail cache when files are deleted permanently
  - bugfixes
  - translation updates
* Thu Feb 17 2011 gber@opensuse.org
- call %%desktop_database_post/un
- call %%icon_theme_cache_post/un
* Thu Feb  3 2011 gber@opensuse.org
- update to version 1.2.1
  - include stock_folder-{copy,move}.png icons
  - bugfixes
* Mon Jan 17 2011 gber@opensuse.org
- update to version 1.2.0
  - bugfixes
* Fri Jan 14 2011 gber@opensuse.org
- recommend rather than require -lang subpackage
- include manpage in main package
* Tue Jan 11 2011 gber@opensuse.org
- remove dependency on xfconf
* Sun Jan  9 2011 gber@opensuse.org
- update to version 1.1.6
  - bugfixes
  - translation updates
- corrected URL
- recommend tumbler
- cleaned up thunar-rpmlintrc
* Wed Dec 29 2010 gber@opensuse.org
- fix patch level and revert change to Thunar-bulk-rename.desktop
  until %%%%suse_update_desktop_file is fixed
* Wed Dec 29 2010 gber@opensuse.org
- fix category of Thunar-bulk-rename.desktop
* Sun Dec 26 2010 gber@opensuse.org
- cleanup
* Sat Dec 25 2010 gber@opensuse.org
- improved summaries/descriptions
- corrected group
- require versioned -lang subpackage
- make the -devel subpackage recommend the -doc subpackage
- symlink thunar -> Thunar manpage
- drop obsolete build dependency on fam-devel
- recommend thunar-volman rather than ivman
- mark documentation as such
- split developer and user documentation
- build -doc subpackage as noarch
- do not install user documentation under /usr/share/doc
* Wed Dec 15 2010 prusnak@opensuse.org
- fix filelist
* Sun Dec  5 2010 prusnak@opensuse.org
- updated to 1.1.5
  - Make .desktop entries installed by Thunar validate against
    desktop-file-utils 0.16 (bug #6655). Patch by Samuli Suominen.
  - Fix missing instruction to load the sendto model (bug #6762).
  - Fix the sample D-Bus client for the org.xfce.FileManager interface.
  - Fix home folder being displayed as "Desktop" if $HOME is set to
    /home/username/Desktop.
  - Fix outdated Thunar D-Bus API usage in the trash panel applet.
  - Create user dirs instead of showing an error if they don't exist.
  - Allow scrolling in the 'Open With' combo box of the file properties
    dialog (bug #3055).
  - Expand filenames starting with './' based on the current working
    directory instead of home (bug #3451).
  - Print an error if thunar-settings fails to contact the file manager
    service (bug #6547).
  - Permanently delete files if at least one of them cannot be trashed
    (bug #6748).
  - Fix a typo in configure.in.in (bug #6724).
  - Include panel macro header (bug #6680).
  - Use GTK_STOCK_FILE as the fallback icon for files (bug #6662).
  - Fix compiler warnings about shadowed variables.
  - Use Name field as display name of desktop entries (bug #6860).
  - Fix a memory leak in thunar_transfer_job_execute().
  - Fix a segmentation fault when reloading files.
  - Avoid GIO 2.20 function calls.
  - Properly avoid launching the file manager recursively by checking
    the GAppInfo id/name.
  - Translation updates: Hungarian, German, Slovak,
    Portuguese (Brazilian), Chinese (China), Greek, Catalan (Valencian),
    Italian, Basque, Spanish (Castilian), Kazakh, Portuguese, Hebrew,
    Galician, Indonesian, Chinese (Taiwan), Japanese,
* Wed Dec  1 2010 prusnak@opensuse.org
- use pkgconfig symbol in BuildRequires
* Sat Jul 17 2010 bernhard@bwalle.de
- updated to 1.0.2
  * Build fixes for GIT and some cleanups.
  * Fix make distcheck.
  * Work around png 1.4 API change.
  * Umask < 0022 not honoured (bug #5813 and #3532).
  * Translation updates (el, es, it, gl, pl, ru, tr, ro, lv, ur,
    ur_PK, ast, hu, kk, nn, nl, am, bn, sk, ug).
- Drop thunar-libpng14.patch.
* Fri May 28 2010 andrea@opensuse.org
- removed info pages prerequires (no info pages to install)
- fixed -doc subpackage RPM group
* Mon May 24 2010 andrea@opensuse.org
- split libthunarx-1-2 and libthunar-vfs-1-2 to reduce packages
  dependencies
- added fdupes to make rpmlint happy
- move %%%%_datadir/doc/Thunar to -doc subpackage to make
  rpmlint happy
- fixed -devel subpackage RPM Group
- split -lang subpackage to reduce main package size and make
  rpmlint happy
* Thu Apr  8 2010 pgajdos@suse.cz
- build with libpng14
* Thu Mar 18 2010 prusnak@suse.cz
- added xfconf to BuildRequires/Requires
* Tue Nov  3 2009 coolo@novell.com
- updated patches to apply with fuzz=0
* Tue Apr 21 2009 prusnak@suse.cz
- updated to 1.0.1
  * Put quotes around filenames in thunar-wallpaper-plugin (bug #5056)
  * Apply umask properly when creating files/directories.
    Patch by Giovanni Bechis (bug #3532).
* Fri Feb 27 2009 prusnak@suse.cz
- updated to 1.0.0 (Xfce 4.6.0 release)
- removed obsolete patches:
  * thunar-vfs-volume-hal_missing-audio-cds-for-volman.patch
  * thunar-use-eject-where-necessary.patch
* Wed Jan 28 2009 prusnak@suse.cz
- added libexif-devel to BuildRequires
* Mon Jan 26 2009 crrodriguez@suse.de
- remove the remaining "la" files that references "libhal*.la" (1/2)
- enable-pcre used but pcre-devel not buildRequired
- needs fno-strict-aliasing to run correctly
* Wed Oct 29 2008 bwalle@suse.de
- update to Thunar 0.9.3
  o Update to latest trunk translations.
* Wed Dec 12 2007 prusnak@suse.cz
- correct eject function (use-eject-where-necessary.patch)
* Tue Dec  4 2007 prusnak@suse.cz
- fixed typo in vfs-volume-hal_missing-audio-cds-for-volman.patch
* Tue Dec  4 2007 bwalle@suse.de
- disable HAL for 10.0 because of build errors
* Mon Dec  3 2007 bwalle@suse.de
- update to Thunar 0.9.0
  o Do not display volumes without mountable file systems
  o Properly recognize OGG files as audio files for custom actions
  o Add new date renamer
  o Pass the correct $DISPLAY value to processes spawned by Thunar
    and xfdesktop in multi screen environments
  o Preselect the whole filename when renaming folders
  o Prevent infinite recursion on JPEG files with broken EXIF data
  o Fix crash on amd64
  o Add support to retry job based operations.
  o Display more details in the override dialog
  o Add support for different date/time formats
  o Fix crash on sparc64
  o Properly binaries selected for custom actions
  o Fix invalid invocation of thunar-volman for volumes that should
    be ignored
  o Reduce binary size by stripping XML comments and whitespace
  o Use the correct HAL property to determine whether a given volume
    or device requires eject
  o Automatically disable thumbnailing if storing a thumbnail fails
    because of a fatal error
  o Fix crash because of unaligned memory access
  o Fix compilation with the Sun Studio 11 compiler
  o Updated translations
* Wed Aug 15 2007 bwalle@suse.de
- moved /usr/lib{,64}/thunarx-1 from -devel package into main
  package because these files are actually plugins
* Wed Jul 18 2007 prusnak@suse.cz
- disable translating of Thunar-folder-handler desktop file
  for distributions before 10.2
- replaced obsoleted %%run_ldconfig macro with /sbin/ldconfig
* Sat Jun 23 2007 bwalle@suse.de
- replaced group 'System/GUI/Other' by 'System/GUI/Xfce'
* Tue Jun 19 2007 prusnak@suse.cz
- use %%fdupes, moved some files to -devel subpackage
* Mon Jun 11 2007 sbrabec@suse.cz
- Removed invalid desktop Category "Application" from spec file
  (#254654).
* Thu Jun  7 2007 sbrabec@suse.cz
- Removed invalid desktop Category "Application" (#254654).
* Tue May 22 2007 prusnak@suse.cz
- call %%suse_update_desktop_file
* Tue May 22 2007 prusnak@suse.cz
- sync with BuildService
- fixed desktop file
* Sun Jan 21 2007 bwalle@suse.de
- removed halmount patch, is no longer required
- upgraded to 0.8.0
* Wed Nov  8 2006 bwalle@suse.de
- added halmount patch, hope that it gets upstream
  (Xfce Bugzilla #2556)
- Recommends ivman
* Sat Nov  4 2006 bwalle@suse.de
- updated to 4.3.99.2 (4.4 rc2)
* Tue Sep  5 2006 bwalle@suse.de
- updated to 0.4.0rc1
- added xfce4-panel-devel as BuildRequires to build panel trash applet
* Mon Sep  4 2006 pnemec@suse.cz
- updated to new version
- new files
* Fri Aug 25 2006 bernhard.walle@gmx.de
- changed 'startup-notification' to 'startup-notification-devel' as BuildRequires
- added fam-devel as BuildRequires to build with FAM support
- added gconf2-devel as BuildRequires to build with preview support
- fixed typo in the description of -devel
- added hal-devel as Requires in the -devel package
- added startup-notification as BuildRequires for SUSE 10.0
- added gconf2-devel as BuildRequires for -devel
- added fam-devel as BuildRequires for -devel
- added startup-notification-devel as BuildRequires for -devel
* Wed Aug 23 2006 pnemec@suse.cz
- added dbus-devel to build requires
  - added hal support
  - added startup notification
* Tue Aug  1 2006 pnemec@suse.cz
- initial comment, version is 0.3.2beta2
- package moved into BuildService
- added thunar-desktop_file.patch - small modification of desktop file
